summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/Makefile.am2
-rw-r--r--tdecore/kdebug.areas58
-rw-r--r--tdecore/knotifyclient.h2
-rw-r--r--tdecore/ksimpledirwatch.cpp2
-rw-r--r--tdecore/ksimpledirwatch.h2
-rw-r--r--tdecore/ksimpledirwatch_p.h2
-rw-r--r--tdecore/kurldrag.cpp6
-rw-r--r--tdecore/network/tdeiobuffer.h4
-rw-r--r--tdecore/network/tdemulticastsocket.h4
-rw-r--r--tdecore/network/tdemulticastsocketdevice.h4
-rw-r--r--tdecore/tdeaboutdata.h4
-rw-r--r--tdecore/tdeaccel.h6
-rw-r--r--tdecore/tdeaccelaction.h6
-rw-r--r--tdecore/tdeaccelbase.h6
-rw-r--r--tdecore/tdeaccelmanager.h4
-rw-r--r--tdecore/tdeaccelmanager_private.h4
-rw-r--r--tdecore/tdeaccelprivate.h6
-rw-r--r--tdecore/tdeapplication.h4
-rw-r--r--tdecore/tdecmdlineargs.h4
-rw-r--r--tdecore/tdeconfig.h4
-rw-r--r--tdecore/tdeconfig_compiler/Makefile.am2
-rw-r--r--tdecore/tdeconfig_compiler/example/Makefile.am4
-rw-r--r--tdecore/tdeconfig_compiler/tests/Makefile.am20
-rw-r--r--tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.cpp4
-rw-r--r--tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.h4
-rw-r--r--tdecore/tdeconfigbackend.h4
-rw-r--r--tdecore/tdeconfigbase.h4
-rw-r--r--tdecore/tdeconfigdata.h4
-rw-r--r--tdecore/tdeconfigdialogmanager.h6
-rw-r--r--tdecore/tdeconfigskeleton.h4
-rw-r--r--tdecore/tdeglobal.h6
-rw-r--r--tdecore/tdeglobalsettings.h4
-rw-r--r--tdecore/tdehw/tderootsystemdevice.cpp4
-rw-r--r--tdecore/tdelibs_export.h16
-rw-r--r--tdecore/tdelocale.cpp4
-rw-r--r--tdecore/tdelocale.h6
-rw-r--r--tdecore/tdemultipledrag.h6
-rw-r--r--tdecore/tdeshortcut.h6
-rw-r--r--tdecore/tdeshortcutlist.h6
-rw-r--r--tdecore/tdeshortcutmenu.h6
-rw-r--r--tdecore/tdestartupinfo.h4
-rw-r--r--tdecore/tdestdaccel.h4
-rw-r--r--tdecore/tdesycoca.cpp8
-rw-r--r--tdecore/tdesycoca.h2
-rw-r--r--tdecore/tdetempfile.h4
-rw-r--r--tdecore/tests/Makefile.am2
-rw-r--r--tdecore/tests/tdeconfigtest.cpp4
-rw-r--r--tdecore/tests/tdeconfigtestgui.h4
48 files changed, 143 insertions, 143 deletions
diff --git a/tdecore/Makefile.am b/tdecore/Makefile.am
index c04ee4c6d..4e3603f4f 100644
--- a/tdecore/Makefile.am
+++ b/tdecore/Makefile.am
@@ -188,7 +188,7 @@ install-exec-hook:
DISTCLEANFILES = tde-config.cpp
-DOXYGEN_REFERENCES = dcop tdeui tdeparts kio
+DOXYGEN_REFERENCES = dcop tdeui tdeparts tdeio
DOXYGEN_EXCLUDE = malloc kde_file.h
DOXYGEN_SET_WARN_IF_UNDOCUMENTED = YES
diff --git a/tdecore/kdebug.areas b/tdecore/kdebug.areas
index 901aa3460..d503dfb6d 100644
--- a/tdecore/kdebug.areas
+++ b/tdecore/kdebug.areas
@@ -7,10 +7,10 @@
125 tdecore (TDEAccel)
126 tdecore (KURL)
-127 kio (KProtocolInfo)
+127 tdeio (KProtocolInfo)
128 tdecore (KRegExp)
129 tdecore (TDEAction)
-130 kio (KPasswdServer)
+130 tdeio (KPasswdServer)
131 tdecore (TDEAcceleratorManager)
150 tdecore (KLibLoader)
160 tdecore (KNotifyClient)
@@ -183,7 +183,7 @@
5601 kontact (interfaces)
5602 kontact (plugins)
5650 tderesources
-5700 kabc
+5700 tdeabc
5710 tdeabc/vcard
5720 kaddressbook
5800 libkcal
@@ -221,44 +221,44 @@
6210 tdehtml (editor)
# libtdeio
-7000 kio
-7001 kio (KDirWatch)
-7002 kio (Slave)
-7003 kio (KDirLister)
-7004 kio (KDirListerCache)
-7005 kio (Filter)
-7006 kio (Scheduler)
-7007 kio (TDEIOJob)
-7009 kio (KMimeType)
-7010 kio (KRun)
-7011 kio (KSycoca)
-7012 kio (KService*)
-7013 kio (KPing)
-7014 kio (TDETrader)
-7015 kio (KAutoMount)
-7016 kio (TDELauncher)
-7017 kio (KIOConnection)
-7018 kio (KMimeMagic)
-7019 kio (tdeioslave)
+7000 tdeio
+7001 tdeio (KDirWatch)
+7002 tdeio (Slave)
+7003 tdeio (KDirLister)
+7004 tdeio (KDirListerCache)
+7005 tdeio (Filter)
+7006 tdeio (Scheduler)
+7007 tdeio (TDEIOJob)
+7009 tdeio (KMimeType)
+7010 tdeio (KRun)
+7011 tdeio (KSycoca)
+7012 tdeio (KService*)
+7013 tdeio (KPing)
+7014 tdeio (TDETrader)
+7015 tdeio (KAutoMount)
+7016 tdeio (TDELauncher)
+7017 tdeio (KIOConnection)
+7018 tdeio (KMimeMagic)
+7019 tdeio (tdeioslave)
7020 kded
7021 tdebuildsycoca
7022 kurifilter
7023 kurifilter (plugins)
-7024 kio (UIServer)
+7024 tdeio (UIServer)
7025 kpac
-7026 kio (KShred)
-7027 kio (TCPSlaveBase)
-7028 kio (Observer)
+7026 tdeio (KShred)
+7027 tdeio (TCPSlaveBase)
+7028 tdeio (Observer)
7029 kssl
-7030 kio (KEMailSettings)
+7030 tdeio (KEMailSettings)
7031 KImageIO
-7032 kio (KURLCompletion)
+7032 tdeio (KURLCompletion)
7033 KFileMetaInfo
7034 KFileMetainfo (plugins)
7040 KZip
7041 KTar
7042 KAr
-7043 kio (bookmarks)
+7043 tdeio (bookmarks)
# 71xx are for tdeioslaves
7101 tdeio_file
diff --git a/tdecore/knotifyclient.h b/tdecore/knotifyclient.h
index ff96b020a..a824d5a37 100644
--- a/tdecore/knotifyclient.h
+++ b/tdecore/knotifyclient.h
@@ -70,7 +70,7 @@ class TDEInstance;
* <li>catastrophe
*</ul>
*
- * The events can be configured in an application using KNotifyDialog, which is part of KIO.
+ * The events can be configured in an application using KNotifyDialog, which is part of TDEIO.
*
* @author Charles Samuels <charles@kde.org>
*/
diff --git a/tdecore/ksimpledirwatch.cpp b/tdecore/ksimpledirwatch.cpp
index 835566268..a001b5c06 100644
--- a/tdecore/ksimpledirwatch.cpp
+++ b/tdecore/ksimpledirwatch.cpp
@@ -19,7 +19,7 @@
// KSimpleDirWatch is a basic copy of KDirWatch
-// but with the KIO linking requirement removed
+// but with the TDEIO linking requirement removed
#include <config.h>
#include <errno.h>
diff --git a/tdecore/ksimpledirwatch.h b/tdecore/ksimpledirwatch.h
index 4dcae30b7..842a20dcf 100644
--- a/tdecore/ksimpledirwatch.h
+++ b/tdecore/ksimpledirwatch.h
@@ -30,7 +30,7 @@ class KSimpleDirWatchPrivate;
/**
* KSimpleDirWatch is a basic copy of KDirWatch
- * but with the KIO linking requirement removed
+ * but with the TDEIO linking requirement removed
*
* Watch directories and files for changes.
* The watched directories or files don't have to exist yet.
diff --git a/tdecore/ksimpledirwatch_p.h b/tdecore/ksimpledirwatch_p.h
index c295ac957..cf1288064 100644
--- a/tdecore/ksimpledirwatch_p.h
+++ b/tdecore/ksimpledirwatch_p.h
@@ -4,7 +4,7 @@
* because KSimpleDirWatchPrivate has signals and slots
*
* KSimpleDirWatch is a basic copy of KDirWatch
- * but with the KIO linking requirement removed
+ * but with the TDEIO linking requirement removed
*/
#ifndef _KSIMPLEDIRWATCH_P_H
diff --git a/tdecore/kurldrag.cpp b/tdecore/kurldrag.cpp
index 5e64d09b2..a8ab2323a 100644
--- a/tdecore/kurldrag.cpp
+++ b/tdecore/kurldrag.cpp
@@ -128,7 +128,7 @@ bool KURLDrag::decode( const TQMimeSource *e, KURL::List &uris, TQMap<TQString,T
{
if ( decode( e, uris ) ) // first decode the URLs (see above)
{
- TQByteArray ba = e->encodedData( "application/x-kio-metadata" );
+ TQByteArray ba = e->encodedData( "application/x-tdeio-metadata" );
if ( ba.size() )
{
TQString s = ba.data();
@@ -175,7 +175,7 @@ const char * KURLDrag::format( int i ) const
if ( i == 0 )
return "text/uri-list";
else if ( i == 1 )
- return "application/x-kio-metadata";
+ return "application/x-tdeio-metadata";
if ( d && d->m_exportAsText == false )
return 0;
if ( i == 2 )
@@ -230,7 +230,7 @@ TQByteArray KURLDrag::encodedData( const char* mime ) const
a.resize( s.length());
memcpy( a.data(), s.data(), s.length());
}
- else if ( mimetype == "application/x-kio-metadata" )
+ else if ( mimetype == "application/x-tdeio-metadata" )
{
if ( !m_metaData.isEmpty() )
{
diff --git a/tdecore/network/tdeiobuffer.h b/tdecore/network/tdeiobuffer.h
index 88b1db4e7..394af5b7b 100644
--- a/tdecore/network/tdeiobuffer.h
+++ b/tdecore/network/tdeiobuffer.h
@@ -22,8 +22,8 @@
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-#ifndef KIOBUFFER_H
-#define KIOBUFFER_H
+#ifndef TDEIOBUFFER_H
+#define TDEIOBUFFER_H
#include <tqcstring.h>
diff --git a/tdecore/network/tdemulticastsocket.h b/tdecore/network/tdemulticastsocket.h
index 15d3a28ea..09eeb01cd 100644
--- a/tdecore/network/tdemulticastsocket.h
+++ b/tdecore/network/tdemulticastsocket.h
@@ -22,8 +22,8 @@
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-#ifndef KMULTICASTSOCKET_H
-#define KMULTICASTSOCKET_H
+#ifndef TDEMULTICASTSOCKET_H
+#define TDEMULTICASTSOCKET_H
#include "kdatagramsocket.h"
#include "tdemulticastsocketdevice.h"
diff --git a/tdecore/network/tdemulticastsocketdevice.h b/tdecore/network/tdemulticastsocketdevice.h
index bddb048a8..99511b356 100644
--- a/tdecore/network/tdemulticastsocketdevice.h
+++ b/tdecore/network/tdemulticastsocketdevice.h
@@ -22,8 +22,8 @@
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-#ifndef KMULTICASTSOCKETDEVICE_H
-#define KMULTICASTSOCKETDEVICE_H
+#ifndef TDEMULTICASTSOCKETDEVICE_H
+#define TDEMULTICASTSOCKETDEVICE_H
#include "tdesocketdevice.h"
#include "knetworkinterface.h"
diff --git a/tdecore/tdeaboutdata.h b/tdecore/tdeaboutdata.h
index db76287f2..8b1480f84 100644
--- a/tdecore/tdeaboutdata.h
+++ b/tdecore/tdeaboutdata.h
@@ -24,8 +24,8 @@
#include <tqimage.h>
#include <tdelocale.h>
-#ifndef _KABOUTDATA_H_
-#define _KABOUTDATA_H_
+#ifndef _TDEABOUTDATA_H_
+#define _TDEABOUTDATA_H_
class TDEAboutPersonPrivate;
class TDEAboutDataPrivate;
diff --git a/tdecore/tdeaccel.h b/tdecore/tdeaccel.h
index 8b61102f4..2d205885c 100644
--- a/tdecore/tdeaccel.h
+++ b/tdecore/tdeaccel.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KACCEL_H
-#define _KACCEL_H
+#ifndef _TDEACCEL_H
+#define _TDEACCEL_H
#include <tqaccel.h>
#include <tdeshortcut.h>
@@ -387,4 +387,4 @@ class TDECORE_EXPORT TDEAccel : public TQAccel
friend class TDEAccelPrivate;
};
-#endif // _KACCEL_H
+#endif // _TDEACCEL_H
diff --git a/tdecore/tdeaccelaction.h b/tdecore/tdeaccelaction.h
index e8232cc44..1c719541f 100644
--- a/tdecore/tdeaccelaction.h
+++ b/tdecore/tdeaccelaction.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KACCELACTION_H
-#define _KACCELACTION_H
+#ifndef _TDEACCELACTION_H
+#define _TDEACCELACTION_H
#include <tqmap.h>
#include <tqptrvector.h>
@@ -573,4 +573,4 @@ class TDECORE_EXPORT TDEAccelActions
friend class TDEAccelBase;
};
-#endif // _KACCELACTION_H
+#endif // _TDEACCELACTION_H
diff --git a/tdecore/tdeaccelbase.h b/tdecore/tdeaccelbase.h
index 377589718..ecd0ce358 100644
--- a/tdecore/tdeaccelbase.h
+++ b/tdecore/tdeaccelbase.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KACCELBASE_H
-#define _KACCELBASE_H
+#ifndef _TDEACCELBASE_H
+#define _TDEACCELBASE_H
#include <tqmap.h>
#include <tqptrvector.h>
@@ -279,4 +279,4 @@ class TDECORE_EXPORT TDEAccelBase
friend class TDEAccelActions;
};
-#endif // _KACCELBASE_H
+#endif // _TDEACCELBASE_H
diff --git a/tdecore/tdeaccelmanager.h b/tdecore/tdeaccelmanager.h
index 03ee627b3..2ed90f5b5 100644
--- a/tdecore/tdeaccelmanager.h
+++ b/tdecore/tdeaccelmanager.h
@@ -18,8 +18,8 @@
*/
-#ifndef __K_ACCELMANAGER_H__
-#define __K_ACCELMANAGER_H__
+#ifndef __TDE_ACCELMANAGER_H__
+#define __TDE_ACCELMANAGER_H__
class TQWidget;
diff --git a/tdecore/tdeaccelmanager_private.h b/tdecore/tdeaccelmanager_private.h
index ed401801e..d9227e8da 100644
--- a/tdecore/tdeaccelmanager_private.h
+++ b/tdecore/tdeaccelmanager_private.h
@@ -18,8 +18,8 @@
*/
-#ifndef __KACCELMANAGER_PRIVATE_H__
-#define __KACCELMANAGER_PRIVATE_H__
+#ifndef __TDEACCELMANAGER_PRIVATE_H__
+#define __TDEACCELMANAGER_PRIVATE_H__
#include <tqstring.h>
diff --git a/tdecore/tdeaccelprivate.h b/tdecore/tdeaccelprivate.h
index 0d967998d..c91e01f42 100644
--- a/tdecore/tdeaccelprivate.h
+++ b/tdecore/tdeaccelprivate.h
@@ -1,5 +1,5 @@
-#ifndef __KACCELPRIVATE_H
-#define __KACCELPRIVATE_H
+#ifndef __TDEACCELPRIVATE_H
+#define __TDEACCELPRIVATE_H
#include "kkeyserver_x11.h"
#include <tqtimer.h>
@@ -50,4 +50,4 @@ class TDECORE_EXPORT TDEAccelPrivate : public TQObject, public TDEAccelBase
bool eventFilter( TQObject* pWatched, TQEvent* pEvent ); // virtual method from QObject
};
-#endif // !__KACCELPRIVATE_H
+#endif // !__TDEACCELPRIVATE_H
diff --git a/tdecore/tdeapplication.h b/tdecore/tdeapplication.h
index f2f776a2f..a5dc3fcec 100644
--- a/tdecore/tdeapplication.h
+++ b/tdecore/tdeapplication.h
@@ -18,8 +18,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KAPP_H
-#define _KAPP_H
+#ifndef _TDEAPP_H
+#define _TDEAPP_H
// Version macros. Never put this further down.
#include "tdeversion.h"
diff --git a/tdecore/tdecmdlineargs.h b/tdecore/tdecmdlineargs.h
index 9b7dc0f4f..8705b4d35 100644
--- a/tdecore/tdecmdlineargs.h
+++ b/tdecore/tdecmdlineargs.h
@@ -16,8 +16,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KCMDLINEARGS_H_
-#define _KCMDLINEARGS_H_
+#ifndef _TDECMDLINEARGS_H_
+#define _TDECMDLINEARGS_H_
#include "tdelibs_export.h"
#include <kurl.h>
diff --git a/tdecore/tdeconfig.h b/tdecore/tdeconfig.h
index c2da06446..2ae0549de 100644
--- a/tdecore/tdeconfig.h
+++ b/tdecore/tdeconfig.h
@@ -19,8 +19,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KCONFIG_H
-#define _KCONFIG_H
+#ifndef _TDECONFIG_H
+#define _TDECONFIG_H
class TQTimer;
diff --git a/tdecore/tdeconfig_compiler/Makefile.am b/tdecore/tdeconfig_compiler/Makefile.am
index d5141f102..ba622d6f0 100644
--- a/tdecore/tdeconfig_compiler/Makefile.am
+++ b/tdecore/tdeconfig_compiler/Makefile.am
@@ -4,7 +4,7 @@ AM_CPPFLAGS = -I$(top_srcdir)/tdecore -I$(top_srcdir) $(all_includes)
bin_PROGRAMS = tdeconfig_compiler
-tdeconfig_compiler_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+tdeconfig_compiler_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
tdeconfig_compiler_LDADD = $(LIB_TDECORE)
tdeconfig_compiler_SOURCES = tdeconfig_compiler.cpp
diff --git a/tdecore/tdeconfig_compiler/example/Makefile.am b/tdecore/tdeconfig_compiler/example/Makefile.am
index 612788f6b..da7aecc9b 100644
--- a/tdecore/tdeconfig_compiler/example/Makefile.am
+++ b/tdecore/tdeconfig_compiler/example/Makefile.am
@@ -3,11 +3,11 @@ AM_CPPFLAGS = -I$(top_srcdir)/tdecore -I$(top_srcdir) $(all_includes)
check_PROGRAMS = example # autoexample
EXTRA_PROGRAMS = autoexample
-example_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+example_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
example_LDADD = $(LIB_TDECORE)
example_SOURCES = example.cpp exampleprefs_base.cpp
-autoexample_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+autoexample_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
autoexample_LDADD = $(LIB_TDECORE) $(LIB_TDEUI)
autoexample_SOURCES = exampleprefs_base.cpp general_base.ui myoptions_base.ui \
autoexample.cpp
diff --git a/tdecore/tdeconfig_compiler/tests/Makefile.am b/tdecore/tdeconfig_compiler/tests/Makefile.am
index fa88f0b4b..e82db3536 100644
--- a/tdecore/tdeconfig_compiler/tests/Makefile.am
+++ b/tdecore/tdeconfig_compiler/tests/Makefile.am
@@ -14,43 +14,43 @@ CLEANFILES = test1.cpp test1.h \
test_dpointer.cpp test_dpointer.h \
md5sums
-test1_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test1_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test1_LDADD = $(LIB_TDECORE)
test1_SOURCES = test1main.cpp test1.cpp
-test2_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test2_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test2_LDADD = $(LIB_TDECORE)
test2_SOURCES = test2main.cpp test2.cpp
-test3_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test3_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test3_LDADD = $(LIB_TDECORE)
test3_SOURCES = test3main.cpp test3.cpp
-test4_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test4_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test4_LDADD = $(LIB_TDECORE)
test4_SOURCES = test4main.cpp test4.cpp
-test5_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test5_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test5_LDADD = $(LIB_TDECORE)
test5_SOURCES = test5main.cpp test5.cpp
-test6_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test6_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test6_LDADD = $(LIB_TDECORE)
test6_SOURCES = test6main.cpp test6.cpp
-test7_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test7_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test7_LDADD = $(LIB_TDECORE)
test7_SOURCES = test7main.cpp test7.cpp
-test8_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test8_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test8_LDADD = $(LIB_TDECORE)
test8_SOURCES = test8main.cpp test8a.cpp test8b.cpp
-test9_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test9_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test9_LDADD = $(LIB_TDECORE)
test9_SOURCES = test9main.cpp test9.cpp
-test_dpointer_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+test_dpointer_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
test_dpointer_LDADD = $(LIB_TDECORE)
test_dpointer_SOURCES = test_dpointer_main.cpp test_dpointer.cpp
diff --git a/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.cpp b/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.cpp
index e5bb3dcea..158d008a0 100644
--- a/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.cpp
+++ b/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.cpp
@@ -21,8 +21,8 @@
using namespace KUnitTest;
-KUNITTEST_MODULE( tdeunittest_tdeconfigcompiler_test, "TDEConfigXT")
-KUNITTEST_MODULE_REGISTER_TESTER( TDEConfigCompiler_Test )
+TDEUNITTEST_MODULE( tdeunittest_tdeconfigcompiler_test, "TDEConfigXT")
+TDEUNITTEST_MODULE_REGISTER_TESTER( TDEConfigCompiler_Test )
typedef const char * CompilerTestSet[];
diff --git a/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.h b/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.h
index df3f4cf37..bdebfe283 100644
--- a/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.h
+++ b/tdecore/tdeconfig_compiler/tests/tdeconfigcompiler_test.h
@@ -13,8 +13,8 @@
*************************************************************************
*/
-#ifndef KCONFIGCOMPILER_TEST_H
-#define KCONFIGCOMPILER_TEST_H
+#ifndef TDECONFIGCOMPILER_TEST_H
+#define TDECONFIGCOMPILER_TEST_H
#include <tdeunittest/tester.h>
diff --git a/tdecore/tdeconfigbackend.h b/tdecore/tdeconfigbackend.h
index 83c8047bc..c4149a69c 100644
--- a/tdecore/tdeconfigbackend.h
+++ b/tdecore/tdeconfigbackend.h
@@ -19,8 +19,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KCONFIGBACKEND_H
-#define _KCONFIGBACKEND_H
+#ifndef _TDECONFIGBACKEND_H
+#define _TDECONFIGBACKEND_H
#include "tdeconfigdata.h"
#include <tdeconfigbase.h>
diff --git a/tdecore/tdeconfigbase.h b/tdecore/tdeconfigbase.h
index a1ddbb4d3..a891409e7 100644
--- a/tdecore/tdeconfigbase.h
+++ b/tdecore/tdeconfigbase.h
@@ -20,8 +20,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KCONFIGBASE_H
-#define _KCONFIGBASE_H
+#ifndef _TDECONFIGBASE_H
+#define _TDECONFIGBASE_H
#include <tqobject.h>
#include <tqcolor.h>
diff --git a/tdecore/tdeconfigdata.h b/tdecore/tdeconfigdata.h
index f99f72c08..d5b8824d0 100644
--- a/tdecore/tdeconfigdata.h
+++ b/tdecore/tdeconfigdata.h
@@ -19,8 +19,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KCONFIGDATA_H
-#define _KCONFIGDATA_H
+#ifndef _TDECONFIGDATA_H
+#define _TDECONFIGDATA_H
#include <tqmap.h> // generic red-black tree class
#include "tdelibs_export.h"
diff --git a/tdecore/tdeconfigdialogmanager.h b/tdecore/tdeconfigdialogmanager.h
index 1b82e9eda..ecb3640ea 100644
--- a/tdecore/tdeconfigdialogmanager.h
+++ b/tdecore/tdeconfigdialogmanager.h
@@ -18,8 +18,8 @@
* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301, USA.
*/
-#ifndef KCONFIGDIALOGMANAGER_H
-#define KCONFIGDIALOGMANAGER_H
+#ifndef TDECONFIGDIALOGMANAGER_H
+#define TDECONFIGDIALOGMANAGER_H
#include <tqobject.h>
#include <tqptrlist.h>
@@ -232,5 +232,5 @@ private:
};
-#endif // KCONFIGDIALOGMANAGER_H
+#endif // TDECONFIGDIALOGMANAGER_H
diff --git a/tdecore/tdeconfigskeleton.h b/tdecore/tdeconfigskeleton.h
index b260db1e8..825c74400 100644
--- a/tdecore/tdeconfigskeleton.h
+++ b/tdecore/tdeconfigskeleton.h
@@ -20,8 +20,8 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef _KCONFIGSKELETON_H
-#define _KCONFIGSKELETON_H
+#ifndef _TDECONFIGSKELETON_H
+#define _TDECONFIGSKELETON_H
#include <tqcolor.h>
#include <tqdatetime.h>
diff --git a/tdecore/tdeglobal.h b/tdecore/tdeglobal.h
index a1a8114be..b5fddb834 100644
--- a/tdecore/tdeglobal.h
+++ b/tdecore/tdeglobal.h
@@ -15,8 +15,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _KGLOBAL_H
-#define _KGLOBAL_H
+#ifndef _TDEGLOBAL_H
+#define _TDEGLOBAL_H
#include "tdelibs_export.h"
#include <kinstance.h> // KDE4: class TDEInstance is enough here
@@ -247,5 +247,5 @@ int TDECORE_EXPORT kasciistricmp( const char *str1, const char *str2 );
* KDE environment.
*/
-#endif // _KGLOBAL_H
+#endif // _TDEGLOBAL_H
diff --git a/tdecore/tdeglobalsettings.h b/tdecore/tdeglobalsettings.h
index 0e11426d2..ec286d2e4 100644
--- a/tdecore/tdeglobalsettings.h
+++ b/tdecore/tdeglobalsettings.h
@@ -15,8 +15,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _KGLOBALSETTINGS_H
-#define _KGLOBALSETTINGS_H
+#ifndef _TDEGLOBALSETTINGS_H
+#define _TDEGLOBALSETTINGS_H
#include <tqstring.h>
#include <tqcolor.h>
diff --git a/tdecore/tdehw/tderootsystemdevice.cpp b/tdecore/tdehw/tderootsystemdevice.cpp
index 3f12b4d5a..774bc091a 100644
--- a/tdecore/tdehw/tderootsystemdevice.cpp
+++ b/tdecore/tdehw/tderootsystemdevice.cpp
@@ -382,7 +382,7 @@ bool TDERootSystemDevice::canPowerOff() {
#else // WITH_CONSOLEKIT
// FIXME
// Can we power down this system?
- // This should probably be checked via DCOP and therefore interface with KDM
+ // This should probably be checked via DCOP and therefore interface with TDM
if (config->readBoolEntry( "offerShutdown", true )/* && DM().canShutdown()*/) { // FIXME
maysd = true;
}
@@ -424,7 +424,7 @@ bool TDERootSystemDevice::canReboot() {
#else // WITH_CONSOLEKIT
// FIXME
// Can we power down this system?
- // This should probably be checked via DCOP and therefore interface with KDM
+ // This should probably be checked via DCOP and therefore interface with TDM
if (config->readBoolEntry( "offerShutdown", true )/* && DM().canShutdown()*/) { // FIXME
mayrb = true;
}
diff --git a/tdecore/tdelibs_export.h b/tdecore/tdelibs_export.h
index e59837feb..7d2ab7db2 100644
--- a/tdecore/tdelibs_export.h
+++ b/tdecore/tdelibs_export.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KDELIBS_EXPORT_H
-#define _KDELIBS_EXPORT_H
+#ifndef _TDELIBS_EXPORT_H
+#define _TDELIBS_EXPORT_H
/* needed for KDE_EXPORT macros */
#include <kdemacros.h>
@@ -36,10 +36,10 @@
#define TDEUI_EXPORT KDE_EXPORT
#define TDEFX_EXPORT KDE_EXPORT
#define TDEPRINT_EXPORT KDE_EXPORT
-#define KDNSSD_EXPORT KDE_EXPORT
+#define TDEDNSSD_EXPORT KDE_EXPORT
#define TDEIO_EXPORT KDE_EXPORT
#define DCOP_EXPORT KDE_EXPORT
-#define KPARTS_EXPORT KDE_EXPORT
+#define TDEPARTS_EXPORT KDE_EXPORT
#define KTEXTEDITOR_EXPORT KDE_EXPORT
#define KABC_EXPORT KDE_EXPORT
#define TDESU_EXPORT KDE_EXPORT
@@ -48,14 +48,14 @@
#define TDESTYLE_EXPORT KDE_EXPORT
#define TDEHTML_EXPORT KDE_EXPORT
#define KMDI_EXPORT KDE_EXPORT
-#define KUTILS_EXPORT KDE_EXPORT
+#define TDEUTILS_EXPORT KDE_EXPORT
#define KATEPARTINTERFACES_EXPORT KDE_EXPORT
#define KATEPART_EXPORT KDE_EXPORT
#define KMID_EXPORT KDE_EXPORT
#define TDERANDR_EXPORT KDE_EXPORT
-#define KIMPROXY_EXPORT KDE_EXPORT
+#define TDEIMPROXY_EXPORT KDE_EXPORT
#define KDE_ARTS_EXPORT KDE_EXPORT
-#define KUNITTEST_EXPORT KDE_EXPORT
+#define TDEUNITTEST_EXPORT KDE_EXPORT
#define KPATH_SEPARATOR ':'
@@ -65,7 +65,7 @@
#endif
-#endif /*_KDELIBS_EXPORT_H*/
+#endif /*_TDELIBS_EXPORT_H*/
/* workaround for tdecore: stupid moc's grammar doesn't accept two macros
between 'class' keyword and <classname>: */
diff --git a/tdecore/tdelocale.h b/tdecore/tdelocale.h
index 94cf704f1..4bee48dde 100644
--- a/tdecore/tdelocale.h
+++ b/tdecore/tdelocale.h
@@ -19,8 +19,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _KLOCALE_H
-#define _KLOCALE_H
+#ifndef _TDELOCALE_H
+#define _TDELOCALE_H
#include <tqstring.h>
#include <tdelibs_export.h>
@@ -1188,7 +1188,7 @@ private:
void initFormat(TDEConfig *config);
/**
- * @internal Initializes the catalogs appname, tdelibs and kio for all chosen languages.
+ * @internal Initializes the catalogs appname, tdelibs and tdeio for all chosen languages.
*
* @param config The configuration object used for init
* @param useEnv True if we should use environment variables
diff --git a/tdecore/tdemultipledrag.h b/tdecore/tdemultipledrag.h
index 42baf3530..4b9a05e80 100644
--- a/tdecore/tdemultipledrag.h
+++ b/tdecore/tdemultipledrag.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef KMULTIPLEDRAG_H
-#define KMULTIPLEDRAG_H
+#ifndef TDEMULTIPLEDRAG_H
+#define TDEMULTIPLEDRAG_H
#ifndef QT_NO_DRAGANDDROP
@@ -102,4 +102,4 @@ private:
#endif // QT_NO_DRAGANDDROP
-#endif // KMULTIPLEDRAG_H
+#endif // TDEMULTIPLEDRAG_H
diff --git a/tdecore/tdeshortcut.h b/tdecore/tdeshortcut.h
index e98a007b5..09f7fce05 100644
--- a/tdecore/tdeshortcut.h
+++ b/tdecore/tdeshortcut.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef __KSHORTCUT_H
-#define __KSHORTCUT_H
+#ifndef __TDESHORTCUT_H
+#define __TDESHORTCUT_H
#include <tqkeysequence.h>
#include <tqstring.h>
@@ -848,4 +848,4 @@ class TDECORE_EXPORT TDEShortcut
#endif
};
-#endif // __KSHORTCUT_H
+#endif // __TDESHORTCUT_H
diff --git a/tdecore/tdeshortcutlist.h b/tdecore/tdeshortcutlist.h
index 99e83766b..9c45b6d0e 100644
--- a/tdecore/tdeshortcutlist.h
+++ b/tdecore/tdeshortcutlist.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef __KSHORTCUTLIST_H
-#define __KSHORTCUTLIST_H
+#ifndef __TDESHORTCUTLIST_H
+#define __TDESHORTCUTLIST_H
#include <tqglobal.h> // For uint
#include <tqstring.h>
@@ -292,4 +292,4 @@ class TDECORE_EXPORT ShortcutList : public TDEShortcutList
};
}
-#endif // __KSHORTCUTLIST_H
+#endif // __TDESHORTCUTLIST_H
diff --git a/tdecore/tdeshortcutmenu.h b/tdecore/tdeshortcutmenu.h
index a62757316..ece721942 100644
--- a/tdecore/tdeshortcutmenu.h
+++ b/tdecore/tdeshortcutmenu.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef __KSHORTCUTMENU_H
-#define __KSHORTCUTMENU_H
+#ifndef __TDESHORTCUTMENU_H
+#define __TDESHORTCUTMENU_H
#include <tqmap.h>
#include <tqpopupmenu.h>
@@ -58,4 +58,4 @@ class TDECORE_EXPORT TDEShortcutMenu : public TQPopupMenu
IndexToKKeySequence m_seqs;
};
-#endif // __KSHORTCUTMENU_H
+#endif // __TDESHORTCUTMENU_H
diff --git a/tdecore/tdestartupinfo.h b/tdecore/tdestartupinfo.h
index 3f8310f6b..9fa57cd4b 100644
--- a/tdecore/tdestartupinfo.h
+++ b/tdecore/tdestartupinfo.h
@@ -22,8 +22,8 @@ DEALINGS IN THE SOFTWARE.
****************************************************************************/
-#ifndef __KSTARTUPINFO_H
-#define __KSTARTUPINFO_H
+#ifndef __TDESTARTUPINFO_H
+#define __TDESTARTUPINFO_H
#include <sys/types.h>
#include <tqobject.h>
diff --git a/tdecore/tdestdaccel.h b/tdecore/tdestdaccel.h
index 3914794f6..e39b090b9 100644
--- a/tdecore/tdestdaccel.h
+++ b/tdecore/tdestdaccel.h
@@ -17,8 +17,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KSTDACCEL_H
-#define KSTDACCEL_H
+#ifndef TDESTDACCEL_H
+#define TDESTDACCEL_H
#include <tqstring.h>
#include <tdeshortcut.h>
diff --git a/tdecore/tdesycoca.cpp b/tdecore/tdesycoca.cpp
index 8f5ede967..a11175117 100644
--- a/tdecore/tdesycoca.cpp
+++ b/tdecore/tdesycoca.cpp
@@ -82,7 +82,7 @@ public:
int KSycoca::version()
{
- return KSYCOCA_VERSION;
+ return TDESYCOCA_VERSION;
}
// Read-only constructor
@@ -181,7 +181,7 @@ bool KSycoca::openDatabase( bool openDummyIfNotFound )
buffer->setBuffer(TQByteArray());
buffer->open(IO_ReadWrite);
m_str = new TQDataStream( buffer);
- (*m_str) << (TQ_INT32) KSYCOCA_VERSION;
+ (*m_str) << (TQ_INT32) TDESYCOCA_VERSION;
(*m_str) << (TQ_INT32) 0;
}
else
@@ -309,9 +309,9 @@ bool KSycoca::checkVersion(bool abortOnError)
m_str->device()->at(0);
TQ_INT32 aVersion;
(*m_str) >> aVersion;
- if ( aVersion < KSYCOCA_VERSION )
+ if ( aVersion < TDESYCOCA_VERSION )
{
- kdWarning(7011) << "Found version " << aVersion << ", expecting version " << KSYCOCA_VERSION << " or higher." << endl;
+ kdWarning(7011) << "Found version " << aVersion << ", expecting version " << TDESYCOCA_VERSION << " or higher." << endl;
if (!abortOnError) return false;
kdError(7011) << "Outdated database ! Stop kded and restart it !" << endl;
abort();
diff --git a/tdecore/tdesycoca.h b/tdecore/tdesycoca.h
index 4b43d4607..f8e2274e0 100644
--- a/tdecore/tdesycoca.h
+++ b/tdecore/tdesycoca.h
@@ -35,7 +35,7 @@ class KSycocaFactoryList;
* If the existing file is outdated, it will not get read
* but instead we'll ask kded to regenerate a new one...
*/
-#define KSYCOCA_VERSION 94
+#define TDESYCOCA_VERSION 94
/**
* @internal
diff --git a/tdecore/tdetempfile.h b/tdecore/tdetempfile.h
index abc78ffbf..d9a71385c 100644
--- a/tdecore/tdetempfile.h
+++ b/tdecore/tdetempfile.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KTEMPFILE_H_
-#define _KTEMPFILE_H_
+#ifndef _TDETEMPFILE_H_
+#define _TDETEMPFILE_H_
#include <tqstring.h>
#include <stdio.h>
diff --git a/tdecore/tests/Makefile.am b/tdecore/tests/Makefile.am
index a831eb65c..73e06f588 100644
--- a/tdecore/tests/Makefile.am
+++ b/tdecore/tests/Makefile.am
@@ -82,5 +82,5 @@ ktimezonestest_SOURCES = ktimezonestest.cpp
check_LTLIBRARIES = tdeunittest_tdeconfig.la
tdeunittest_tdeconfig_la_SOURCES = tdeconfigtest.cpp
-tdeunittest_tdeconfig_la_LIBADD = $(LIB_KUNITTEST)
+tdeunittest_tdeconfig_la_LIBADD = $(LIB_TDEUNITTEST)
tdeunittest_tdeconfig_la_LDFLAGS = -module $(KDE_CHECK_PLUGIN)
diff --git a/tdecore/tests/tdeconfigtest.cpp b/tdecore/tests/tdeconfigtest.cpp
index d9c89d6d4..a6ef7aa5b 100644
--- a/tdecore/tests/tdeconfigtest.cpp
+++ b/tdecore/tests/tdeconfigtest.cpp
@@ -31,8 +31,8 @@ private:
void revertEntries();
};
-KUNITTEST_MODULE( tdeunittest_tdeconfig, "TDEConfigTest" )
-KUNITTEST_MODULE_REGISTER_TESTER( TDEConfigTest )
+TDEUNITTEST_MODULE( tdeunittest_tdeconfig, "TDEConfigTest" )
+TDEUNITTEST_MODULE_REGISTER_TESTER( TDEConfigTest )
// test data
#define BOOLENTRY1 true
diff --git a/tdecore/tests/tdeconfigtestgui.h b/tdecore/tests/tdeconfigtestgui.h
index 4aa50cb5f..a7cfd1356 100644
--- a/tdecore/tests/tdeconfigtestgui.h
+++ b/tdecore/tests/tdeconfigtestgui.h
@@ -16,8 +16,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _KCONFIG_TEST_H
-#define _KCONFIG_TEST_H
+#ifndef _TDECONFIG_TEST_H
+#define _TDECONFIG_TEST_H
#include <tdeapplication.h>
#include <tqdialog.h>
diff --git a/tdecore/tdelocale.cpp b/tdecore/tdelocale.cpp
index 4402dd183..f841d7375 100644
--- a/tdecore/tdelocale.cpp
+++ b/tdecore/tdelocale.cpp
@@ -137,7 +137,7 @@ void TDELocale::initMainCatalogues(const TQString & catalog)
d->catalogNames.append( mainCatalogue ); // application catalog
if (mainCatalogue.contains("desktop") == 0 || mainCatalogue.contains("kdesktop") == 1) { //don't bother if we're looking up desktop translations
d->catalogNames.append( SYSTEM_MESSAGES ); // always include tdelibs.mo
- d->catalogNames.append( "kio" ); // always include kio.mo
+ d->catalogNames.append( "tdeio" ); // always include tdeio.mo
d->catalogNames.append( "xdg-user-dirs" );
}
updateCatalogues(); // evaluate this for all languages
@@ -440,7 +440,7 @@ bool TDELocale::setLanguage(const TQStringList & languages)
// 1) some empty strings that we have to eliminate
// 2) duplicate entries like in de:fr:de, where we have to keep the first occurrance of a language in order
// to preserve the order of precenence of the user => iterate backwards
// 3) languages into which the application is not translated. For those languages we should not even load tdelibs.mo or kio.po.
// these langugage have to be dropped. Otherwise we get strange side effects, e.g. with Hebrew:
// the right/left switch for languages that write from
// right to left (like Hebrew or Arabic) is set in tdelibs.mo. If you only have tdelibs.mo
@@ -440,7 +440,7 @@ bool TDELocale::setLanguage(const TQStringList & languages)
// 2) duplicate entries like in de:fr:de, where we have to keep the first occurrance of a language in order
// to preserve the order of precenence of the user => iterate backwards
- // 3) languages into which the application is not translated. For those languages we should not even load tdelibs.mo or kio.po.
+ // 3) languages into which the application is not translated. For those languages we should not even load tdelibs.mo or tdeio.po.
// these langugage have to be dropped. Otherwise we get strange side effects, e.g. with Hebrew:
// the right/left switch for languages that write from